# Lolicon

![CI](https://github.com/hentai-chan/lolicon/workflows/CI/badge.svg)
![CodeQL](https://github.com/hentai-chan/lolicon/workflows/CodeQL/badge.svg)
![PyPI](https://github.com/hentai-chan/lolicon/workflows/PyPI/badge.svg)
[![PyPI](https://img.shields.io/pypi/v/lolicon?label=Release)](https://pypi.org/project/lolicon/)
[![CodeFactor](https://www.codefactor.io/repository/github/hentai-chan/lolicon/badge?s=73446cb8092f75fb1c893e480473680065734a05)](https://www.codefactor.io/repository/github/hentai-chan/lolicon)
[![codecov](https://codecov.io/gh/hentai-chan/lolicon/branch/master/graph/badge.svg?token=7KX4DQSZBV)](https://codecov.io/gh/hentai-chan/lolicon)
![Python](https://img.shields.io/badge/Python-%203.8%20%7C%203.9-blue)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)

```bash
Development Status :: 3 - Alpha
```

## About this Project

This is a work in progress. Expect frequent changes to the API. More information
will follow soon.
